#!/bin/sh

BASEDIR=/usr/local/oberon
BINDIR=$BASEDIR/bin
CDBDDIR=$BASEDIR/var/cdbd
CDBDIR=/pub/cdb/oberon
INTENSITY=$BASEDIR/etc/intensity/cdbd
ONS_ROOT=127.0.0.1:9880

cmdname=`basename $0`
usage="Usage $cmdname [-c cdbdir] [-d cdbddir] [-g gid] [-u uid] [-r ons_root]"

cdbdir="$CDBDIR"
cdbddir="$CDBDDIR"
uidgidflags=""
root="$ONS_ROOT"
intensity="$INTENSITY"
set -- `getopt c:d:g:u:r: $*`
while [ $# -gt 0 ]
do
   case $1
   in -c)
      cdbdir="$2"; shift 2
   ;; -d)
      cdbddir="$2"; shift 2
   ;; -g)
      uidgidflags="$uidgidflags -g $2"
      shift 2
   ;; -u)
      uidgidflags="$uidgidflags -u $2"
      shift 2
   ;; -r)
      root="$2"
      shift 2
   ;; --)
      shift; break
   ;; *)
      echo >&2 "$usage"; exit 1
   esac
done

echo "#!/bin/sh
#------------------------------------------------------------------------------
# generated by $cmdname at `date`
# CDBD (Compiler Database Daemon)
#------------------------------------------------------------------------------
### BEGIN INIT INFO
# Provides: cdbd
# Required-Start: \$network \$remote_fs \$named pons
# Short-Description: Compiler Database Daemon
# Default-Start: 3 5
# Default-Stop: 0 1 2 6
# Description: CDBD (Compiler Database Daemon) is an object-oriented
#    database for program text sources and compilation results
### END INIT INFO

start_service() {
   ONS_ROOT=\"$root\"
   export ONS_ROOT
   echo -n \"Starting CDBD \"
   $BINDIR/onsmkdir -p \"$cdbdir\"
   INTENSITY=\"$intensity\"
   ioptions=
   if [ -f \$INTENSITY ]
   then
      ioptions=\"-i \`cat \$INTENSITY\`\"
   fi
   startproc $uidgidflags -l \"$cdbddir\"/cdbd.LOG \\
      $BINDIR/cdbd \\
	 $ioptions \\
	 -b \"$cdbdir\" \\
	 -w \"$cdbddir\"/write \\
	 \"$cdbddir\"/oberon.db
   rc_status -v
}

stop_service() {
   echo -n \"Shutting down CDBD \"
   killproc -TERM $BINDIR/cdbd
   rc_status -v
}

. /etc/rc.status
rc_reset

cd \"$cdbddir\" || exit 1

case \"\$1\"
in start)
   start_service
;; stop)
   stop_service
;; restart)
   stop_service
   start_service
;; status)
   echo -n \"Checking for service CDBD \"
   checkproc $BINDIR/cdbd
   rc_status -v
;; *)
   echo >&2 \"Usage: \$0 start|stop|restart|status\"
esac"
